==> nextcloud-27.1.4.tgz: nextcloud/apps/oauth2/l10n/is.js <==
OC.L10N.register(
    "oauth2",
    {
    "Your client is not authorized to connect. Please inform the administrator of your client." : "Biðlarinn þinn hefur ekki heimild til að tengjast. Láttu kerfisstjórann þinn vita.",
    "Your redirect URL needs to be a full URL for example: https://yourdomain.com/path" : "URL-endurbeiningarslóðin verður að vera full URL-slóð, til dæmis: https://yourdomain.com/path",
    "OAuth 2.0" : "OAuth 2.0",
    "Allows OAuth2 compatible authentication from other web applications." : "Gerir kleift að nota OAuth2-samhæfða auðkenningu frá öðrum vefforritum.",
    "The OAuth2 app allows administrators to configure the built-in authentication workflow to also allow OAuth2 compatible authentication from other web applications." : "OAuth2-forritið gerir kerfisstjórum kleift að stilla innbyggða auðkenningarferlið þannig að einnig sé hægt að nota OAuth2-samhæfða auðkenningu frá öðrum vefforritum.",
    "OAuth 2.0 clients" : "OAuth 2.0 biðlarar",
    "OAuth 2.0 allows external services to request access to {instanceName}." : "OAuth 2.0 gerir utanaðkomandi þjónustum kleift að biðja um aðgang að {instanceName}.",
    "Name" : "Nafn",
    "Redirection URI" : "Endurbeiningarslóð",
    "Client Identifier" : "Biðlaraauðkenni",
    "Secret key" : "Leynilykill",
    "Add client" : "Bæta við biðlara",
    "Add" : "Bæta við",
    "Show client secret" : "Sýna leynilykil biðlara",
    "Delete" : "Eyða",
    "Secret" : "Leynilykill"
},
"nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");

==> nextcloud-28.0.14.tgz: nextcloud/apps/oauth2/l10n/is.js <==
OC.L10N.register(
    "oauth2",
    {
    "Your client is not authorized to connect. Please inform the administrator of your client." : "Biðlarinn þinn hefur ekki heimild til að tengjast. Láttu kerfisstjórann þinn vita.",
    "Your redirect URL needs to be a full URL for example: https://yourdomain.com/path" : "URL-endurbeiningarslóðin verður að vera full URL-slóð, til dæmis: https://yourdomain.com/path",
    "OAuth 2.0" : "OAuth 2.0",
    "Allows OAuth2 compatible authentication from other web applications." : "Gerir kleift að nota OAuth2-samhæfða auðkenningu frá öðrum vefforritum.",
    "The OAuth2 app allows administrators to configure the built-in authentication workflow to also allow OAuth2 compatible authentication from other web applications." : "OAuth2-forritið gerir kerfisstjórum kleift að stilla innbyggða auðkenningarferlið þannig að einnig sé hægt að nota OAuth2-samhæfða auðkenningu frá öðrum vefforritum.",
    "OAuth 2.0 clients" : "OAuth 2.0 biðlarar",
    "OAuth 2.0 allows external services to request access to {instanceName}." : "OAuth 2.0 gerir utanaðkomandi þjónustum kleift að biðja um aðgang að {instanceName}.",
    "Name" : "Nafn",
    "Redirection URI" : "Endurbeiningarslóð",
    "Client Identifier" : "Biðlaraauðkenni",
    "Secret key" : "Leynilykill",
    "Delete client" : "Eyða biðlara",
    "Add client" : "Bæta við biðlara",
    "Add" : "Bæta við",
    "Delete" : "Eyða",
    "Show client secret" : "Sýna leynilykil biðlara"
},
"nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
